/**
 * @file common.cl
 * Common parameters for advection and remeshing kernels.
 */

inline uint noBC_id(int id);

#ifdef WITH_NOBC
/**
 * Mapping to local memory arrays to avoir banck conflics.
 * 1D buffer is taken as 2D one with wor-items vs. particles.
 *
 * @param id 1D index
 *
 * @return 2D index
 */
inline uint noBC_id(int id){
  return (id%PART_NB_PER_WI)*WI_NB+(id/PART_NB_PER_WI);
}
#else
/**
 * Leave mapping unchanged, 1D.
 *
 * @param id 1D index
 *
 * @return 1D index
 */
inline uint noBC_id(int id){
  return id;
}
#endif

/**
 * Constants for remeshing formulas:
 *  - M4PRIME
 *  - M6PRIME
 *  - M8PRIME
 *  - L6STAR
 */
#define M4PRIME 1
#define M6PRIME 2
#define M8PRIME 3
#define L6STAR 4
#define L4STAR 5
