/**
 * @file weights.cl
 * Remeshing formulas, vectorized version.
 * Polynomials under Horner form.
 */

#if FORMULA == M4PRIME

inline float__N__ alpha(float__N__ y){
  return ((y * (y * (-y + 2.0) - 1.0)) / 2.0);}
inline float__N__ beta(float__N__ y){
  return ((y * y * (3.0 * y - 5.0) + 2.0) / 2.0);}
inline float__N__ gamma(float__N__ y){
  return ((y * (y * (-3.0 * y + 4.0) + 1.0)) / 2.0);}
inline float__N__ delta(float__N__ y){
  return ((y * y * (y - 1.0)) / 2.0);}


#elif FORMULA == M6PRIME

inline float__N__ alpha(float__N__ y){
  return (y * (y * (y * (y * (13.0 - 5.0 * y) - 9.0) - 1.0) + 2.0) / 24.0);}
inline float__N__ beta(float__N__ y){
  return (y * (y * (y * (y * (25.0 * y - 64.0) + 39.0) + 16.0) - 16.0) / 24.0);}
inline float__N__ gamma(float__N__ y){
  return (y * y * (y * (y * (126.0 - 50.0 * y) - 70.0) - 30.0) / 24.0 + 1.0);}
inline float__N__ delta(float__N__ y){
  return (y * (y * (y * (y * (50.0 * y - 124.0) + 66.0) + 16.0) + 16.0) / 24.0);}
inline float__N__ eta(float__N__ y){
  return (y * (y * (y * (y * (61.0 - 25.0 * y) - 33.0) - 1.0) - 2.0) / 24.0);}
inline float__N__ zeta(float__N__ y){
  return (y * y * y * (y * (5.0 * y - 12.0) + 7.0) / 24.0);}


#elif FORMULA == M8PRIME

inline float__N__ alpha(float__N__ y){
  return ((y*(y*(y*(y*(y*(y*(-10.0*y + 21.0) + 28.0) - 105.0) + 70.0) + 35.0) - 56.0) + 17.0) / 3360.0);}
inline float__N__ beta(float__N__ y){
  return ((y*(y*(y*(y*(y*(y*(70.0*y - 175.0) - 140.0) + 770.0) - 560.0) - 350.0) + 504.0) - 102.0) / 3360.0);}
inline float__N__ gamma(float__N__ y){
  return ((y*(y*(y*(y*(y*(y*(-210.0*y + 609.0) + 224.0) - 2135.0) + 910.0) + 2765.0) - 2520.0) + 255.0) / 3360.0);}
inline float__N__ delta(float__N__ y){
  return ((y*y* (y*y* (y*y* (70.0*y - 231.0) + 588.0) - 980.0) + 604.0) / 672.0);}
inline float__N__ eta(float__N__ y){
  return ((y*(y*(y*(y*(y*(y*(-70.0*y+ 259.0) - 84.0) - 427.0) - 182.0)+ 553.0) + 504.0)+ 51.0) / 672.0);}
inline float__N__ zeta(float__N__ y){
  return ((y*(y*(y*(y*(y*(y*(210.0*y- 861.0) + 532.0) + 770.0) + 560.0) - 350.0) - 504.0) - 102.0) / 3360.0);}
inline float__N__ theta(float__N__ y){
  return ((y* (y* (y* (y* (y* (y* (-70.0* y+ 315.0) -280.0) -105.0) -70.0) +35.0)+ 56.0) +17.0) / 3360.0);}
inline float__N__ iota(float__N__ y){
  return ((y * y * y * y * y * (y * (10.0 * y - 49.0) + 56.0)) / 3360.0);}


#elif FORMULA == L6STAR

inline float__N__ alpha(float__N__ y){
  return (((-12.0 + (4.0 + (15.0 + (140.0 + (-370.0 + (312.0 - 89.0 * y) * y) * y) * y) * y) * y) * y) / 720.0);}
inline float__N__ beta(float__N__ y){
  return (((108.0 + (-54.0 + (-120.0 + (-955.0 + (2581.0 + (-2183.0 + 623.0 * y) * y) * y) * y) * y) * y ) * y) / 720.0);}
inline float__N__ gamma(float__N__ y){
  return (((-180.0 + (180.0 + (65.0 + (950.0 + (-2574.0 + (2182.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 240.0);}
inline float__N__ delta(float__N__ y){
  return ( 1.0 + ((-196.0 + (-959.0 + (2569.0 + (-2181.0 + 623.0 * y) * y) * y) * y * y ) * y * y) / 144.0);}
inline float__N__ eta(float__N__ y){
  return (((108.0 + (108.0 + (-39.0 + (976.0 + (-2566.0 + (2180.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 144.0);}
inline float__N__ zeta(float__N__ y){
  return (((-36.0 + (-18.0 + (40.0 + (-995.0 + (2565.0 + (-2179.0 + 623.0 * y) * y) * y) * y) * y) * y) * y) / 240.0);}
inline float__N__ theta(float__N__ y){
  return (((12.0 + (4.0 + (-15.0 + (1010.0 + (-2566.0 + (2178.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 720.0);}
inline float__N__ iota(float__N__ y){
  return (((-145.0 + (367.0 + (-311.0 + 89.0 * y) * y) * y) * y * y * y * y) / 720.0);}
#endif
