/**
 * @file weights_noVec.cl
 * Remeshing formulas, basic version.
 * Polynomials under Horner form.
 */

#if FORMULA == M4PRIME

inline float alpha(float y){
  return ((y * (y * (-y + 2.0) - 1.0)) / 2.0);}
inline float beta(float y){
  return ((y * y * (3.0 * y - 5.0) + 2.0) / 2.0);}
inline float gamma(float y){
  return ((y * (y * (-3.0 * y + 4.0) + 1.0)) / 2.0);}
inline float delta(float y){
  return ((y * y * (y - 1.0)) / 2.0);}


#elif FORMULA == M6PRIME

inline float alpha(float y){
  return (y * (y * (y * (y * (13.0 - 5.0 * y) - 9.0) - 1.0) + 2.0) / 24.0);}
inline float beta(float y){
  return (y * (y * (y * (y * (25.0 * y - 64.0) + 39.0) + 16.0) - 16.0) / 24.0);}
inline float gamma(float y){
  return (y * y * (y * (y * (126.0 - 50.0 * y) - 70.0) - 30.0) / 24.0 + 1.0);}
inline float delta(float y){
  return (y * (y * (y * (y * (50.0 * y - 124.0) + 66.0) + 16.0) + 16.0) / 24.0);}
inline float eta(float y){
  return (y * (y * (y * (y * (61.0 - 25.0 * y) - 33.0) - 1.0) - 2.0) / 24.0);}
inline float zeta(float y){
  return (y * y * y * (y * (5.0 * y - 12.0) + 7.0) / 24.0);}

#elif FORMULA == L4STAR

/* L4 star C2*/

inline float alpha(float y){
  return ((2.0+(-1.0+(-9.0+(13.0-5.0*y)*y)*y)*y)*y / 24.0);}
inline float beta(float y){
  return ((-16.0+(16.0+(39.0+(-64.0+25.0*y)*y)*y)*y)*y / 24.0);}
inline float gamma(float y){
  return ((-30.0+(-70.0+(126.0-50.0*y)*y)*y)*y*y / 24.0 + 1.0);}
inline float delta(float y){
  return ((16.0+(16.0+(66.0+(-124.0+50.0*y)*y)*y)*y)*y / 24.0);}
inline float eta(float y){
  return ((-2.0+(-1.0+(-33.0+(61.0-25.0*y)*y)*y)*y)*y / 24.0);}
inline float zeta(float y){
return ((7.0+(-12.0+5.0*y)*y)*y*y*y / 24.0);}


/* L4 star C3*/
/*
inline float alpha(float y){
  return ((2.0+(-1.0+(-2.0+(-22.0+(58.0+(-49.0+14.0*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float beta(float y){
  return ((-16.0+(16.0+(4.0+(111.0+(-290.0+(245.0-70.0*y)*y)*y)*y)*y)*y)*y/ 24.0);}
inline float gamma(float y){
  return ((-30.0+(-224.0+(580.0+(-490.0+140.0*y)*y)*y)*y*y)*y*y / 24.0 + 1.0);}
inline float delta(float y){
  return ((16.0+(16.0+(-4.0+(226.0+(-580.0+(490.0-140.0*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float eta(float y){
  return ((-2.0+(-1.0+(2.0+(-114.0+(290.0+(-245.0+70.0*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float zeta(float y){
return ((23.0+(-58.0+(49.0-14.0*y)*y)*y)*y*y*y*y / 24.0);}*/

/* L4 star C4*/
/*
inline float alpha(float y){
  return ((2.0+(-1.0+(-2.0+(1.0+(-80.0+(273.0+(-354.0+(207.0-46.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float beta(float y){
  return ((-16.0+(16.0+(4.0+(-4.0+(400.0+(-1365.0+(1770.0+(-1035.0+230.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float gamma(float y){
  return ((-30.0+(6.0+(-800.0+(2730.0+(-3540.0+(2070.0-460.0*y)*y)*y)*y)*y)*y*y)*y*y / 24.0 + 1.0);}
inline float delta(float y){
  return ((16.0+(16.0+(-4.0+(-4.0+(800.0+(-2730.0+(3540.0+(-2070.0+460.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float eta(float y){
  return ((-2.0+(-1.0+(2.0+(1.0+(-400.0+(1365.0+(-1770.0+(1035.0-230.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 24.0);}
inline float zeta(float y){
return ((80.0+(-273.0+(354.0+(-207.0+46.0*y)*y)*y)*y)*y*y*y*y*y / 24.0);}*/


#elif FORMULA == M8PRIME

inline float alpha(float y){
  return ((y*(y*(y*(y*(y*(y*(-10.0*y + 21.0) + 28.0) - 105.0) + 70.0) + 35.0) - 56.0) + 17.0) / 3360.0);}
inline float beta(float y){
  return ((y*(y*(y*(y*(y*(y*(70.0*y - 175.0) - 140.0) + 770.0) - 560.0) - 350.0) + 504.0) - 102.0) / 3360.0);}
inline float gamma(float y){
  return ((y*(y*(y*(y*(y*(y*(-210.0*y + 609.0) + 224.0) - 2135.0) + 910.0) + 2765.0) - 2520.0) + 255.0) / 3360.0);}
inline float delta(float y){
  return ((y*y* (y*y* (y*y* (70.0*y - 231.0) + 588.0) - 980.0) + 604.0) / 672.0);}
inline float eta(float y){
  return ((y*(y*(y*(y*(y*(y*(-70.0*y+ 259.0) - 84.0) - 427.0) - 182.0)+ 553.0) + 504.0)+ 51.0) / 672.0);}
inline float zeta(float y){
  return ((y*(y*(y*(y*(y*(y*(210.0*y- 861.0) + 532.0) + 770.0) + 560.0) - 350.0) - 504.0) - 102.0) / 3360.0);}
inline float theta(float y){
  return ((y* (y* (y* (y* (y* (y* (-70.0* y+ 315.0) -280.0) -105.0) -70.0) +35.0)+ 56.0) +17.0) / 3360.0);}
inline float iota(float y){
  return ((y * y * y * y * y * (y * (10.0 * y - 49.0) + 56.0)) / 3360.0);}


#elif FORMULA == L6STAR
/*L6 star C3*/
/*
inline float alpha(float y){
  return (((-12.0 + (4.0 + (15.0 + (140.0 + (-370.0 + (312.0 - 89.0 * y) * y) * y) * y) * y) * y) * y) / 720.0);}
inline float beta(float y){
  return (((108.0 + (-54.0 + (-120.0 + (-955.0 + (2581.0 + (-2183.0 + 623.0 * y) * y) * y) * y) * y) * y ) * y) / 720.0);}
inline float gamma(float y){
  return (((-180.0 + (180.0 + (65.0 + (950.0 + (-2574.0 + (2182.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 240.0);}
inline float delta(float y){
  return ( 1.0 + ((-196.0 + (-959.0 + (2569.0 + (-2181.0 + 623.0 * y) * y) * y) * y * y ) * y * y) / 144.0);}
inline float eta(float y){
  return (((108.0 + (108.0 + (-39.0 + (976.0 + (-2566.0 + (2180.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 144.0);}
inline float zeta(float y){
  return (((-36.0 + (-18.0 + (40.0 + (-995.0 + (2565.0 + (-2179.0 + 623.0 * y) * y) * y) * y) * y) * y) * y) / 240.0);}
inline float theta(float y){
  return (((12.0 + (4.0 + (-15.0 + (1010.0 + (-2566.0 + (2178.0 - 623.0 * y) * y) * y) * y) * y) * y) * y) / 720.0);}
inline float iota(float y){
return (((-145.0 + (367.0 + (-311.0 + 89.0 * y) * y) * y) * y * y * y * y) / 720.0);}*/

/*L6 star C4*/
/*
inline float alpha(float y){
  return ((-12.0+(4.0+(15.0+(-5.0+(500.0+(-1718.0+(2231.0+(-1305.0+290.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float beta(float y){
  return ((108.0+(-54.0+(-120.0+(60.0+(-3509.0+(12027.0+(-15617.0+(9135.0-2030.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float gamma(float y){
  return ((-540.0+(540.0+(195.0+(-195.0+(10548.0+(-36084.0+(46851.0+(-27405.0+6090.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float delta(float y){
  return ( 1.0 + (-980.0+(280.0+(-17605.0+(60145.0+(-78085.0+(45675.0-10150.0*y)*y)*y)*y)*y)*y*y)*y*y / 720.0);}
inline float eta(float y){
  return ((540.0+(540.0+(-195.0+(-195.0+(17620.0+(-60150.0+(78085.0+(-45675.0+10150.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float zeta(float y){
  return ((-108.0+(-54.0+(120.0+(60.0+(-10575.0+(36093.0+(-46851.0+(27405.0-6090.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float theta(float y){
  return ((12.0+(4.0+(-15.0+(-5.0+(3524.0+(-12032.0+(15617.0+(-9135.0+2030.0*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float iota(float y){
return ((-503.0+(1719.0+(-2231.0+(1305.0-290.0*y)*y)*y)*y)*y*y*y*y*y / 720.0);}*/


/*L6 star C5*/
/*
inline float alpha(float y){
  return ((-12.0+(4.0+(15.0+(-5.0+(-3.0+(1803.0+(-7829.0+(13785.0+(-12285.0+(5533.0-1006.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float beta(float y){
  return ((108.0+(-54.0+(-120.0+(60.0+(12.0+(-12620.0+(54803.0+(-96495.0+(85995.0+(-38731.0+7042.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float gamma(float y){
  return ((-540.0+(540.0+(195.0+(-195.0+(-15.0+(37857.0+(-164409.0+(289485.0+(-257985.0+(116193.0-21126.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float delta(float y){
  return ( 1.0 + (-980.0+(280.0+(-63090.0+(274015.0+(-482475.0+(429975.0+(-193655.0+35210.0*y)*y)*y)*y)*y)*y*y)*y*y)*y*y / 720.0);}
inline float eta(float y){
  return ((540.0+(540.0+(-195.0+(-195.0+(15.0+(63085.0+(-274015.0+(482475.0+(-429975.0+(193655.0-35210.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float zeta(float y){
  return ((-108.0+(-54.0+(120.0+(60.0+(-12.0+(-37848.0+(164409.0+(-289485.0+(257985.0+(-116193.0+21126.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float theta(float y){
  return ((12.0+(4.0+(-15.0+(-5.0+(3.0+(12615.0+(-54803.0+(96495.0+(-85995.0+(38731.0-7042.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float iota(float y){
return ((-1802.0+(7829.0+(-13785.0+(12285.0+(-5533.0+1006.0*y)*y)*y)*y)*y)*y*y*y*y*y*y / 720.0);}*/


/*L6 star C6*/

inline float alpha(float y){
  return ((-12.0+(4.0+(15.0+(-5.0+(-3.0+(1.0+(6587.0+(-34869.0+(77815.0+(-93577.0+(63866.0+(-23426.0+3604.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float beta(float y){
  return ((108.0+(-54.0+(-120.0+(60.0+(12.0+(-6.0+(-46109.0+(244083.0+(-544705.0+(655039.0+(-447062.0+(163982.0-25228.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float gamma(float y){
  return ((-540.0+(540.0+(195.0+(-195.0+(-15.0+(15.0+(138327.0+(-732249.0+(1634115.0+(-1965117.0+(1341186.0+(-491946.0+75684.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float delta(float y){
  return ( 1.0 + (-980.0+(280.0+(-20.0+(-230545.0+(1220415.0+(-2723525.0+(3275195.0+(-2235310.0+(819910.0-126140.0*y)*y)*y)*y)*y)*y)*y)*y*y)*y*y)*y*y / 720.0);}
inline float eta(float y){
  return ((540.0+(540.0+(-195.0+(-195.0+(15.0+(15.0+(230545.0+(-1220415.0+(2723525.0+(-3275195.0+(2235310.0+(-819910.0+126140.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float zeta(float y){
  return ((-108.0+(-54.0+(120.0+(60.0+(-12.0+(-6.0+(-138327.0+(732249.0+(-1634115.0+(1965117.0+(-1341186.0+(491946.0-75684.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float theta(float y){
  return ((12.0+(4.0+(-15.0+(-5.0+(3.0+(1.0+(46109.0+(-244083.0+(544705.0+(-655039.0+(447062.0+(-163982.0+25228.0*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y)*y / 720.0);}
inline float iota(float y){
return ((-6587.0+(34869.0+(-77815.0+(93577.0+(-63866.0+(23426.0-3604.0*y)*y)*y)*y)*y)*y)*y*y*y*y*y*y*y / 720.0);}


#endif
