/**
 * @file weights_noVec_builtin.cl
 * Remeshing formulas, basic version, use of builtin OpenCL fma.
 * Polynomials under Horner form.
 */

#if FORMULA == M4PRIME
inline float alpha(float y){
  return (y*fma(y,fma(y,-1.0, 2.0), - 1.0)/2.0);}
inline float beta(float y){
  return (fma(y*y, fma(y, 3.0, -5.0), 2.0) / 2.0);}
inline float gamma(float   y){
  return ((y * fma(y , fma(-3.0, y, 4.0), 1.0)) / 2.0);}
inline float delta(float y){
  return ((y * y * fma(1.0, y, - 1.0)) / 2.0);}

#elif FORMULA == M6PRIME
inline float alpha(float y){
  return (y * fma(y , fma(y , fma(y , fma(-5.0, y, 13.0),- 9.0),- 1.0), 2.0) / 24.0);}
inline float beta(float y){
  return (y * fma(y , fma(y , fma(y , fma(25.0 , y ,- 64.0), 39.0) , 16.0), - 16.0) / 24.0);}
inline float gamma(float y){
  return (y * y * fma(y , fma(y , fma( - 50.0 , y, 126.0) ,- 70.0) ,- 30.0) / 24.0 + 1.0);}
inline float delta(float y){
  return (y * fma(y , fma(y, fma(y, fma(50.0, y, - 124.0), 66.0) , 16.0) , 16.0) / 24.0);}
inline float eta(float y){
  return (y * fma(y , fma(y , fma(y , fma(- 25.0 , y, 61.0), - 33.0), - 1.0), - 2.0) / 24.0);}
inline float zeta(float y){
  return (y * y * y * fma(y , fma(5.0 , y ,- 12.0) , 7.0) / 24.0);}

#elif FORMULA == M8PRIME
inline float alpha(float y){
  return (fma(y,fma(y,fma(y,fma(y,fma(y,fma(y,fma(-10.0,y, + 21.0), + 28.0), - 105.0), + 70.0), + 35.0), - 56.0), + 17.0) / 3360.0);}
inline float beta(float y){
  return (fma(y,fma(y,fma(y,fma(y,fma(y,fma(y,fma(70.0,y, - 175.0), - 140.0), + 770.0), - 560.0), - 350.0), + 504.0), - 102.0) / 3360.0);}
inline float gamma(float y){
  return (fma(y,fma(y,fma(y,fma(y,fma(y,fma(y,fma(-210.0,y, + 609.0), + 224.0), - 2135.0), + 910.0), + 2765.0), - 2520.0), + 255.0) / 3360.0);}
inline float delta(float y){
  return (fma(y*y, fma(y*y, fma(y*y, fma(70.0,y, - 231.0), + 588.0), - 980.0), + 604.0) / 672.0);}
inline float eta(float y){
  return (fma(y,fma(y,fma(y,fma(y,fma(y,fma(y,fma(-70.0,y, 259.0), - 84.0), - 427.0), - 182.0), + 553.0), + 504.0), + 51.0) / 672.0);}
inline float zeta(float y){
  return (fma(y,fma(y,fma(y,fma(y,fma(y,fma(y,fma(210.0,y,- 861.0), + 532.0), + 770.0), + 560.0), - 350.0), - 504.0), - 102.0) / 3360.0);}
inline float theta(float y){
  return (fma(y, fma(y, fma(y, fma(y, fma(y, fma(y, fma(-70.0, y, 315.0), -280.0), -105.0), -70.0), 35.0), 56.0), 17.0) / 3360.0);}
inline float iota(float y){
return ((y * y * y * y * y * fma(y , fma(10.0 , y ,- 49.0) , 56.0)) / 3360.0);}

#elif FORMULA == L6STAR
inline float alpha(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(-89.0, y, 312.0), -370.0), 140.0), 15.0), 4.0), -12.0)) / 720.0);}
inline float beta(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(623.0, y, -2183.0), 2581.0), -955.0), -120.0), -54.0), 108.0)) / 720.0);}
inline float gamma(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(-623.0, y, 2182.0), -2574.0), 950.0), 65.0), 180.0), -180.0)) / 240.0);}
inline float delta(float y){
  return ((y * y * fma(y * y, fma(y, fma(y, fma(623.0, y, -2181.0), 2569.0), -959.0), -196.0)) / 144.0 + 1.0);}
inline float eta(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(-623.0, y, 2180.0), -2566.0), 976.0), -39.0), 108.0), 108.0)) / 144.0);}
inline float zeta(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(623.0, y, -2179.0), 2565.0), -995.0), 40.0), -18.0), -36.0)) / 240.0);}
inline float theta(float y){
  return ((y * fma(y, fma(y, fma(y, fma(y, fma(y, fma(-623.0, y, 2178.0), -2566.0), 1010.0), -15.0), 4.0), 12.0)) / 720.0);}
inline float iota(float y){
  return ((y * y * y * y * fma(y, fma(y, fma(89.0, y, -311.0), 367.0), -145.0)) / 720.0);}

#endif








