# -*- coding: utf-8 -*-
"""
@file euler.py

Forward Euler method.
"""
from parmepy.constants import np, PARMES_REAL, ORDER
from parmepy.numerics.integrators.odesolver import ODESolver


class Euler(ODESolver):
    """
    ODESolver implementation for solving an equation system
    with forward Euler method.
    y'(t) = f(t,y)

    y(t_{n+1}) = y(t_n) + dt*f(y(t_n))

    """
    def __init__(self, f=None, dim=1):
        """
        Constructor.

        @param f function f(t,y) : Right hand side of the equation to solve.
        @param dim : dimensions
        @param conditions : function to apply boundary conditions.
        """
        ODESolver.__init__(self, f)
        self.name = 'euler'

    def __call__(self, f, t, dt, y):
        """
        Integration step for Euler Method.
         up = f[t, u(t,x,y,z)].

        @param u : function of position at time t.
        @param f : function of function of position at time t.
        @param t : current time.
        @param dt : time step.
#        """
#        result = y + dt * np.asarray(f(t, y), dtype=PARMES_REAL, order=ORDER)
#        return result

        RHS = f(t, y)

        return y[0] + dt * RHS[0], \
               y[1] + dt * RHS[1], \
               y[2] + dt * RHS[2]

    def __str__(self):
        """ToString method"""
        return "Euler Method"


if __name__ == "__main__":
    print __doc__
    print "- Provided class : Euler"
    print Euler.__doc__
