"""
@file discrete/curl.py

Discretisation of the curl operator
"""
from parmepy.constants import debug
from discrete import DiscreteOperator
from parmepy.tools.timers import timed_function
from parmepy.numerics.differential_operations import Curl


class CurlFD(DiscreteOperator):
    """
    Compute the curl of a discrete field.
    """

    @debug
    def __init__(self, invar, outvar, method=None):
        """
        @param[in] invar : input field
        @param[in,out] outvar : curl of the input field
        @param[in] method : how to compute the curl? Default = finite
        differences, 4th order.
        """
        self.invar = invar
        self.outvar = outvar
        DiscreteOperator.__init__(self, [self.invar, self.outvar], method)
        self.input = [self.invar]
        self.output = [self.outvar]
        self.curlFunction = Curl(self.invar.topology, self.method)

    @debug
    @timed_function
    def apply(self, simulation=None):

        self.curlFunction(self.invar, self.outvar)


if __name__ == "__main__":
    print __doc__
    print "- Provided class : CurlFD"
    print CurlFD.__doc__
