# -*- coding: utf-8 -*-
"""
@file operator/multiphase.py

MultiPhase Rot Grad P
"""
from parmepy.operator.continuous import Operator
from parmepy.operator.discrete.multiphase import Pressure_d
from parmepy.constants import debug


class Pressure(Operator):
    """
    Pressure operator representation
    """

    @debug
    def __init__(self, velocity, vorticity, viscosity, density,
                 resolutions=None, topo=None, ghosts=None, method='',
                 **other_config):
        """
        Constructor.
        Create a Pressure operator from given velocity variables.

        @param velocity ContinuousVectorField : velocity variable.
        """
        Operator.__init__(self, [velocity, vorticity, density], method,
                          topo=topo, ghosts=ghosts, name="Pressure")

        self.velocity = velocity
        self.vorticity = vorticity
        self.density = density
        self.viscosity = viscosity
        self.resolutions = resolutions
        self.config = other_config
        self.input = [self.velocity, self.vorticity, self.density]
        self.output = [self.vorticity]

    @debug
    def setUp(self):
        """
        Pressure operator discretization method.
        Create a discrete Pressure operator from given specifications.
        """
        if self._predefinedTopo is not None:
            topo = self._predefinedTopo
            for v in self.variables:
                self.discreteFields[v] = v.discretize(topo)
        else:
            for v in self.variables:
                # the topology for v ...
                topo = self.domain.getOrCreateTopology(self.domain.dimension,
                                                       self.resolutions[v],
                                                       self.ghosts)
                # ... and the corresponding discrete field
                self.discreteFields[v] = v.discretize(topo)

        self.discreteOperator = \
            Pressure_d(self.discreteFields[self.velocity],
                       self.discreteFields[self.vorticity],
                       self.discreteFields[self.density],
                       method=self.method, **self.config)

        self.discreteOperator.setUp()
        self._isUpToDate = True

if __name__ == "__main__":
    print __doc__
    print "- Provided class : Pressure"
    print Pressure.__doc__
