"""
@file operator/updateGhosts.py

Update ghost points for some fields defined on a specific topology.
"""
from parmepy.operator.continuous import Operator
from parmepy.operator.discrete.updateGhosts import UpdateGhosts_d
from parmepy.constants import debug


class UpdateGhosts(Operator):
    """
    Ghost points synchronization.
    """

    @debug
    def __init__(self, variables, topo=None, method=None, **other_config):
        """
        Constructor. Defines process to update ghosts points of
        the given fields.
        @param  variables: list of fields to be updated.
        @param topo: the topo on which variables must be updated
        """
        Operator.__init__(self, variables, method, topo=topo)

        self.topo = topo

    @debug
    def setUp(self):
        if self.topo is None:
            # if the topology is not set, we take the first
            # topology defined for the first variable.
            # (which means that it must exists, i.e. the var
            # has already been discretized)
            assert len(self.variables[0].discreteFields.keys()) > 0,\
                'No topology has been set and/or the first variable has not\
                been discretized. Please provide a topology in updateGhost\
                constructor.'
            self.topo = self.variables[0].discreteFields.keys()[0]

        # get the discrete fields on topo for all variables
        for v in self.variables:
            self.discreteFields[v] = v.discretize(self.topo)
        # and create the discrete operator
        self.discreteOperator = \
            UpdateGhosts_d(self.discreteFields.values(),
                           self.topo, self.method)

        self.discreteOperator.setUp()
        self._isUpToDate = True


if (__name__ == "__main__"):
    print __doc__
    print "- Provided class : UpdateGhosts"
    print UpdateGhosts.__doc__
